===========================
Create and install projects
===========================

Create a new project with `tarbell newproject <projectname>`
------------------------------------------------------------

Run::

    tarbell newproject

When you're done, run a preview server::

    tarbell switch myprojectname

You can now open up `/path/to/myprojectname` and start editing the "index.html"
file.


Install an existing project with `tarbell install <repository-url>`
-------------------------------------------------------------------

Run::

  tarbell install https://urltorepository.com/projectname

e.g.::

  tarbell install https://github.com/sc3/26thandcalifornia.recoveredfactory.net
